@@ -24,20 +24,7 @@ log = get_logger(__name__)
 # TODO: Consider making these real Python Abstract Base Classes (import abc)            
 
 class Request(object):
-
-    def __init__(self, config, content_type):
-        """
-        Initializes a client object.
-
-        :param root_uri: the base URL of Rexster.
-
-        """
-        self.config = config
-        self.content_type = content_type
-        self._initialize()
-
-    def _initialize(self):
-        pass
+    pass
 
 class Result(object):
     """
@@ -81,9 +68,9 @@ class Result(object):
         """
         raise NotImplementedError
 
-    def get_data(self):
+    def get_map(self):
         """
-        Returns the element's property data.
+        Returns the element's property map.
 
         :rtype: dict
 
