@@ -37,9 +37,6 @@ class Converter(object):
     def to_float(self, value):
         raise NotImplementedError
 
-    def to_bool(self, value):
-        raise NotImplementedError
-
     def to_list(self, value):
         raise NotImplementedError
 
@@ -48,6 +45,3 @@ class Converter(object):
 
     def to_null(self, value):
         raise NotImplementedError
-
-    def to_document(self, value):
-        raise NotImplementedError
