@@ -8,9 +8,7 @@ Vertex and Edge container classes and associated proxy classes.
 
 """
 from .utils import u  # Python 3 unicode
-from .utils import initialize_element, initialize_elements, coerce_id, get_logger
-
-log = get_logger(__name__)
+from .utils import initialize_element, initialize_elements, coerce_id
 
 
 class Element(object):
@@ -18,30 +16,12 @@ class Element(object):
 
     def __init__(self, client):
 
-        # NOTE: moved all private prop defs here so they are declared and
-        # pre-defined in _properties so that setattr works in model NORMAL mode
-
         # Client object
         self._client = client
 
         # Property data
         self._data = {}
 
-        # Result object.
-        self._result = None
-
-        # Vertex Proxy Object
-        self._vertices = None
-
-        # Edge Proxy Object
-        self._edges = None
-
-        # Initialized Flag
-        # Initialize all non-database properties here because when _initialized
-        # is set to True, __setattr__ will assume all non-defined properties 
-        # are database properties and will set them in self._data.
-        self._initialized = True
-
     def _initialize(self, result):
         """
         Initialize the element with the result that was returned by the DB.
@@ -52,10 +32,11 @@ class Element(object):
         :rtype: None
 
         """
+        # Result object.
         self._result = result
 
-        # TODO: Do we really need to make a copy?
-        self._data = result.get_data().copy() 
+        # Property data. # TODO: Do we really need to make a copy?
+        self._data = result.get_map().copy() 
 
         # Sets the element ID to the var defined in Config. Defaults to eid.
         self._set_pretty_id(self._client)
@@ -65,6 +46,10 @@ class Element(object):
         self._vertices = VertexProxy(Vertex,self._client)
         self._edges = EdgeProxy(Edge,self._client)
 
+        # Initialize all non-database properties here because when _initialized
+        # is set to True, __setattr__ will assume all non-defined properties 
+        # are database properties and will set them in self._data.
+        self._initialized = True
        
     @classmethod
     def get_base_type(cls):
@@ -184,7 +169,7 @@ class Element(object):
         # dict_.get() is faster than getattr()
         _initialized = dict_.get("_initialized", False)
 
-        if key in dict_ or _initialized is False or key in self.__class__.__dict__:
+        if key in dict_ or _initialized is False:
             # set the attribute normally
             object.__setattr__(self, key, value)
         else:
@@ -286,26 +271,6 @@ class Element(object):
         representation = "<%s: %s>" % (class_name, element_uri)
         return u(representation)    # Python 3
 
-    def __setstate__(self, state):
-        config = state['_config']
-        client_class = state['_client_class']
-        client = client_class(config)
-        state['_client'] = client
-        state['_vertices'] = VertexProxy(Vertex, client)
-        state['_edges'] = EdgeProxy(Edge, client)
-        del state['_client_class']
-        del state['_config']
-        self.__dict__ = state
-
-    def __getstate__(self):
-        state = self.__dict__.copy() 
-        state['_config'] = self._client.config
-        state['_client_class'] = self._client.__class__
-        del state['_client']
-        del state['_vertices']
-        del state['_edges']
-        return state
-        
     def get(self, name, default_value=None):
         """
         Returns the value of a Python attribute or the default value.
@@ -320,10 +285,9 @@ class Element(object):
 
         """
         # TODO: Why do we need this?
-        return getattr(self, name, default_value)
+        return getattr(self, name, default_vaoue)
 
-
-    def data(self):
+    def map(self):
         """
         Returns the element's property data.
 
@@ -332,17 +296,6 @@ class Element(object):
         """
         return self._data
 
-    def map(self):
-        """
-        Deprecated. Returns the element's property data.
-
-        :rtype: dict
-
-        """
-        log.debug("This is deprecated; use data() instead.")
-        return self.data()
-
-
 
 #
 # Vertices
@@ -369,7 +322,7 @@ class Vertex(Element):
     >>> james = g.vertices.get(3)     # Get a vertex from the database
     >>> james.age = 34                # Set a database property
     >>> james.save()                  # Save the vertex in the database
-    >>> james.data()                   # Get the database property map
+    >>> james.map()                   # Get the database property map
     >>> friends = james.outV("knows") # Return Vertex generator of friends
 
     """  
@@ -424,7 +377,7 @@ class Vertex(Element):
         """
         return VertexProxy
 
-    def outE(self, label=None, start=None, limit=None):
+    def outE(self, label=None):
         """
         Returns the outgoing edges.
 
@@ -434,10 +387,10 @@ class Vertex(Element):
         :rtype: Edge generator
 
         """
-        resp = self._client.outE(self._id, label, start, limit)
+        resp = self._client.outE(self._id,label)
         return initialize_elements(self._client,resp)
 
-    def inE(self, label=None, start=None, limit=None):
+    def inE(self, label=None):
         """
         Returns the incoming edges.
 
@@ -447,10 +400,10 @@ class Vertex(Element):
         :rtype: Edge generator
 
         """
-        resp = self._client.inE(self._id, label, start, limit)
+        resp = self._client.inE(self._id,label)
         return initialize_elements(self._client,resp)
 
-    def bothE(self, label=None, start=None, limit=None):
+    def bothE(self, label=None):
         """
         Returns the incoming and outgoing edges.
 
@@ -460,10 +413,10 @@ class Vertex(Element):
         :rtype: Edge generator
 
         """
-        resp = self._client.bothE(self._id, label, start, limit)
+        resp = self._client.bothE(self._id,label)
         return initialize_elements(self._client,resp)
 
-    def outV(self, label=None, start=None, limit=None):
+    def outV(self, label=None):
         """
         Returns the out-adjacent vertices.
 
@@ -473,10 +426,10 @@ class Vertex(Element):
         :rtype: Vertex generator
 
         """
-        resp = self._client.outV(self._id, label, start, limit)
+        resp = self._client.outV(self._id,label)
         return initialize_elements(self._client,resp)
 
-    def inV(self, label=None, start=None, limit=None):
+    def inV(self, label=None):
         """
         Returns the in-adjacent vertices.
 
@@ -486,10 +439,10 @@ class Vertex(Element):
         :rtype: Vertex generator
 
         """
-        resp = self._client.inV(self._id, label, start, limit)
+        resp = self._client.inV(self._id,label)
         return initialize_elements(self._client,resp)
         
-    def bothV(self, label=None, start=None, limit=None):
+    def bothV(self, label=None):
         """
         Returns all incoming- and outgoing-adjacent vertices.
 
@@ -499,7 +452,7 @@ class Vertex(Element):
         :rtype: Vertex generator
 
         """
-        resp = self._client.bothV(self._id, label, start, limit)
+        resp = self._client.bothV(self._id,label)
         return initialize_elements(self._client,resp)
 
     def save(self):
@@ -548,7 +501,7 @@ class VertexProxy(object):
         # Add element class to Registry so we can initialize query results.
         self.client.registry.add_class(element_class)
 
-    def create(self, _data=None, _keys=None, **kwds):
+    def create(self, _data=None, **kwds):
         """
         Adds a vertex to the database and returns it.
 
@@ -562,7 +515,7 @@ class VertexProxy(object):
 
         """
         data = build_data(_data, kwds)
-        resp = self.client.create_vertex(data, keys=_keys)
+        resp = self.client.create_vertex(data)
         return initialize_element(self.client, resp.results)
 
     def get(self, _id):
@@ -581,7 +534,7 @@ class VertexProxy(object):
         except LookupError:
             return None
         
-    def get_or_create(self, key, value, _data=None, _keys=None, **kwds):
+    def get_or_create(self, key, value, _data=None, **kwds):
         """
         Lookup a vertex in the index and create it if it doesn't exsit.
 
@@ -606,7 +559,7 @@ class VertexProxy(object):
         # EdgeProxy doesn't have this method anyway.
         vertex = self.index.get_unique(key, value)
         if vertex is None:
-            vertex = self.create(_data, keys=_keys, **kwds)
+            vertex = self.create(_data, **kwds)
         return vertex
 
     def get_all(self):
@@ -619,7 +572,7 @@ class VertexProxy(object):
         resp = self.client.get_all_vertices()
         return initialize_elements(self.client, resp)
 
-    def update(self,_id, _data=None, _keys=None, **kwds):
+    def update(self,_id, _data=None, **kwds):
         """
         Updates an element in the graph DB and returns it.
 
@@ -638,7 +591,7 @@ class VertexProxy(object):
         # NOTE: this no longer returns an initialized element because not all 
         # Clients return element data, e.g. Neo4jServer retuns nothing.
         data = build_data(_data, kwds)
-        self.client.update_vertex(_id, _data, keys=_keys)
+        self.client.update_vertex(_id, _data)
 
     def remove_properties(self, _id):
         """
@@ -698,7 +651,7 @@ class Edge(Element):
 
     >>> edge.weight = 0.5             # Set a property
     >>> edge.save()                   # Save properties in DB
-    >>> data = edge.data()            # Return property data
+    >>> data = edge.map()             # Return property data
 
     """
     @classmethod
@@ -851,7 +804,7 @@ class EdgeProxy(object):
         # Add element class to Registry so we can initialize query results.
         self.client.registry.add_class(element_class)
 
-    def create(self, outV, label, inV, _data=None, _keys=None, **kwds):
+    def create(self, outV, label, inV, _data=None, **kwds):
         """
         Creates an edge in the database and returns it.
         
@@ -876,7 +829,7 @@ class EdgeProxy(object):
         assert label is not None
         data = build_data(_data, kwds)
         outV, inV = coerce_vertices(outV, inV)
-        resp = self.client.create_edge(outV, label, inV, data, keys=_keys)
+        resp = self.client.create_edge(outV, label, inV, data)
         return initialize_element(self.client, resp.results)
 
     def get(self,_id):
@@ -906,7 +859,7 @@ class EdgeProxy(object):
         return initialize_elements(self.client, resp)
 
 
-    def update(self,_id, _data=None, _keys=None, **kwds):
+    def update(self,_id, _data=None, **kwds):
         """ 
         Updates an edge in the database and returns it. 
         
@@ -925,7 +878,7 @@ class EdgeProxy(object):
         # NOTE: this no longer returns an initialized element because 
         # not all Clients return element data, e.g. Neo4jServer retuns nothing.
         data = build_data(_data, kwds)
-        return self.client.update_edge(_id, data, keys=_keys)
+        return self.client.update_edge(_id, data)
                     
     def remove_properties(self, _id):
         """
