@@ -399,42 +399,20 @@ class Model(six.with_metaclass(ModelMeta, object)):  # Python 3
         """
         return self._properties.keys()
 
-    def data(self):
+    def map(self):
         """
-        Returns a the element's property data.
+        Returns a dict containing the database property data.
 
         :rtype: dict
 
         """
         data = dict()
-        if self.__mode__ == NORMAL:
-            data = self._data
-
         for key in self._properties: 
             # TODO: make this work for calculated values.
             # Calculated props shouldn't be stored, but components should be.
             data[key] = object.__getattribute__(self, key)
         return data
 
-    def map(self):
-        """
-        Deprecated. Returns the element's property data.
-
-        :rtype: dict
-
-        """
-        log.debug("This is deprecated; use data() instead.")
-        return self.data()
-
-    def __check__(self,data):
-        """
-        Override this method in the child class to throw an exception if the data dictionary is invalid
-        
-        :param data: Collection of parameters to be set for this Model
-        :type data: dict
-
-        """
-        pass
 
 class Node(Model, Vertex):
     """ 
@@ -446,8 +424,6 @@ class Node(Model, Vertex):
 
     Example model declaration::
 
-        # people.py
-
         from bulbs.model import Node
         from bulbs.property import String, Integer
 
@@ -459,7 +435,7 @@ class Node(Model, Vertex):
 
     Example usage::
 
-        >>> from people import Person
+        >>> from person import Person
         >>> from bulbs.neo4jserver import Graph
         >>> g = Graph()
 
@@ -493,8 +469,6 @@ class Node(Model, Vertex):
     #: A dict containing the database Property instances.
     _properties = None
 
-    element_type = None
-
     @classmethod
     def get_element_type(cls, config):
         """
@@ -557,7 +531,6 @@ class Node(Model, Vertex):
 
         """
         data = self._get_property_data()
-        self.__check__(data)
         index_name = self.get_index_name(self._client.config)
         keys = self.get_index_keys()
         self._client.update_indexed_vertex(self._id, data, index_name, keys)
@@ -581,7 +554,6 @@ class Node(Model, Vertex):
         """
         # bundle is an OrderedDict containing data, index_name, and keys
         data, index_name, keys = self.get_bundle(_data, **kwds)
-        self.__check__(data)
         resp = self._client.create_indexed_vertex(data, index_name, keys)
         result = resp.one()
         self._initialize(result)
@@ -603,7 +575,6 @@ class Node(Model, Vertex):
         
         """
         data, index_name, keys = self.get_bundle(_data, **kwds)
-        self.__check__(data)
         resp = self._client.update_indexed_vertex(_id, data, index_name, keys)
         result = resp.one()
         self._initialize(result)
@@ -636,8 +607,6 @@ class Relationship(Model, Edge):
 
     Example usage for an edge between a blog entry node and its creating user::
 
-        # people.py
-
         from bulbs.model import Relationship
         from bulbs.properties import DateTime
         from bulbs.utils import current_timestamp
@@ -651,7 +620,7 @@ class Relationship(Model, Edge):
 
     Example usage::
 
-          >>> from people import Person, Knows
+          >>> from person import Person, Knows
           >>> from bulbs.neo4jserver import Graph
           >>> g = Graph()
 
@@ -671,7 +640,6 @@ class Relationship(Model, Edge):
           >>> friends = james.outV('knows')
 
     """
-    label = None
 
     @classmethod
     def get_label(cls, config):
@@ -734,12 +702,8 @@ class Relationship(Model, Edge):
         :rtype: None
 
         """
-        data = self._get_property_data()
-        self.__check__(data)
-
-        index_name = self.get_index_name(self._client.config)
-        keys = self.get_index_keys()
-        self._client.update_indexed_edge(self._id, data, index_name, keys)
+        data = self._get_property_data()      
+        self._client.update_edge(self._id, data)
 
     #
     # Override the _create and _update methods to customize behavior.
@@ -761,9 +725,7 @@ class Relationship(Model, Edge):
         label = self.get_label(self._client.config)
         outV, inV = coerce_vertices(outV, inV)
         data, index_name, keys = self.get_bundle(_data, **kwds)
-        self.__check__(data)
-        resp = self._client.create_indexed_edge(outV, label, inV, data, index_name, keys)
-        result = resp.one()
+        result = self._client.create_edge(outV, label, inV, data).one()
         self._initialize(result)
         
     def _update(self, _id, _data, kwds):
@@ -783,9 +745,7 @@ class Relationship(Model, Edge):
         
         """
         data, index_name, keys = self.get_bundle(_data, **kwds)
-        self.__check__(data)
-        resp = self._client.update_indexed_edge(_id, data, index_name, keys)
-        result = resp.one()
+        result = self._client.update_edge(_id, data).one()
         self._initialize(result)
 
     def _initialize(self,result):
@@ -832,7 +792,7 @@ class NodeProxy(VertexProxy):
         :param _id: The vertex ID.
         :type _id: int or str
 
-        :param _data: Optional property data dict.
+        :param _data: Opetional property data dict.
         :type _data: dict
 
         :param kwds: Optional property data keyword pairs. 
@@ -926,7 +886,6 @@ class RelationshipProxy(EdgeProxy):
         label = self.element_class.get_label(config)
         return self.index.lookup(label_var,label)
 
-
     def get_property_keys(self):
         """
         Returns a list of all the Property keys.
