@@ -9,7 +9,7 @@ Bulbs supports pluggable backends. This is the Neo4j Server client.
 """
 import re
 
-from bulbs.config import Config, DEBUG, ERROR
+from bulbs.config import Config, DEBUG
 from bulbs.registry import Registry
 from bulbs.utils import get_logger
 
@@ -17,11 +17,9 @@ from bulbs.utils import get_logger
 from bulbs.json import JSONTypeSystem
 from bulbs.base import Client, Response, Result
 from bulbs.rest import Request, RESPONSE_HANDLERS, server_error
-from bulbs.utils import json, build_path, get_file_path, urlsplit
 from bulbs.groovy import GroovyScripts
 
-# TODO: Clean up and generalize Yaml
-from .cypher import Cypher, Yaml
+from bulbs.utils import json, build_path, get_file_path, urlsplit, quote
 
 
 # The default URI
@@ -36,7 +34,7 @@ vertex_path = "node"
 edge_path = "relationship"
 index_path = "index"
 gremlin_path = "ext/GremlinPlugin/graphdb/execute_script"
-cypher_path = "cypher"
+cypher_path = "ext/CypherPlugin/graphdb/execute_query"
 
 
 class Neo4jResult(Result):
@@ -85,7 +83,7 @@ class Neo4jResult(Result):
         neo4j_type = self._parse_type(uri)
         return self.type_map[neo4j_type]
         
-    def get_data(self):
+    def get_map(self):
         """
         Returns the element's property map.
 
@@ -241,7 +239,7 @@ class Neo4jResponse(Response):
         # Temporary hack to catch Gremlin Plugin exceptions that return 200 status
         # See https://github.com/neo4j/community/issues/343
         # Example: '"java.lang.IllegalArgumentException: Unknown property type on..."'
-        if re.search(b"^\"java.(.*).Exception:", content):
+        if re.search("^\"java.(.*).Exception:", content):
             # raise error...
             server_error(response)
         
@@ -354,7 +352,7 @@ class Neo4jClient(Client):
         self.request = self.request_class(self.config, self.type_system.content_type)
 
         # Neo4j supports Gremlin so include the Gremlin-Groovy script library
-        self.scripts = GroovyScripts(self.config)
+        self.scripts = GroovyScripts()
         
         # Also include the Neo4j Server-specific Gremlin-Groovy scripts
         scripts_file = get_file_path(__file__, "gremlin.groovy")
@@ -363,7 +361,6 @@ class Neo4jClient(Client):
         # Add it to the registry. This allows you to have more than one scripts namespace.
         self.registry.add_scripts("gremlin", self.scripts)
         
-
     # Gremlin
 
     def gremlin(self, script, params=None): 
@@ -403,13 +400,13 @@ class Neo4jClient(Client):
         resp = self.request.post(path, params)
 
         # Cypher data hack
+        resp.results = (self.result_class(result[0], self.config) for result in resp.results.data)
         resp.total_size = len(resp.results.data)
-        resp.results = (Neo4jResult(result[0], self.config) for result in resp.results.data)
         return resp
 
     # Vertex Proxy
 
-    def create_vertex(self, data, keys=None):
+    def create_vertex(self, data):
         """
         Creates a vertex and returns the Response.
 
@@ -419,9 +416,9 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        if keys or self.config.autoindex is True:
+        if self.config.autoindex is True:
             index_name = self.config.vertex_index
-            return self.create_indexed_vertex(data, index_name, keys=keys)
+            return self.create_indexed_vertex(data, index_name, keys=None)
         path = vertex_path
         params = self._remove_null_values(data)
         return self.request.post(path, params)
@@ -451,7 +448,7 @@ class Neo4jClient(Client):
         params = None
         return self.gremlin(script, params)
 
-    def update_vertex(self, _id, data, keys=None):
+    def update_vertex(self, _id, data):
         """
         Updates the vertex with the _id and returns the Response.
 
@@ -464,9 +461,9 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        if keys or self.config.autoindex is True:
+        if self.config.autoindex is True:
             index_name = self.config.vertex_index
-            return self.update_indexed_vertex(_id,data,index_name,keys=keys)
+            return self.update_indexed_vertex(_id,data,index_name,keys=None)
         path = self._build_vertex_path(_id,"properties")
         params = self._remove_null_values(data)
         return self.request.put(path, params)
@@ -487,7 +484,7 @@ class Neo4jClient(Client):
         
     # Edge Proxy
 
-    def create_edge(self, outV, label, inV, data=None, keys=None): 
+    def create_edge(self, outV, label, inV, data=None): 
         """
         Creates a edge and returns the Response.
         
@@ -506,9 +503,9 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        if keys or self.config.autoindex is True:
+        if self.config.autoindex is True:
             index_name = self.config.edge_index
-            return self.create_indexed_edge(outV,label,inV,data,index_name,keys=keys)
+            return self.create_indexed_edge(outV,label,inV,data,index_name,keys=None)
         data = self._remove_null_values(data)
         inV_uri = self._build_vertex_uri(inV)
         path = build_path(vertex_path, outV, "relationships")
@@ -540,7 +537,7 @@ class Neo4jClient(Client):
         params = None
         return self.gremlin(script, params)
 
-    def update_edge(self, _id, data, keys=None):
+    def update_edge(self, _id, data):
         """
         Updates the edge with the _id and returns the Response.
 
@@ -553,9 +550,9 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        if keys or self.config.autoindex is True:
+        if self.config.autoindex is True:
             index_name = self.config.edge_index
-            return self.update_indexed_edge(_id,data,index_name,keys=keys)
+            return self.update_indexed_edge(_id,data,index_name,keys=None)
         path = build_path(edge_path,_id,"properties")
         params = self._remove_null_values(data)
         return self.request.put(path, params)
@@ -576,7 +573,7 @@ class Neo4jClient(Client):
 
     # Vertex Container
 
-    def outE(self, _id, label=None, start=None, limit=None):
+    def outE(self, _id, label=None):
         """
         Returns the outgoing edges of the vertex.
 
@@ -590,10 +587,10 @@ class Neo4jClient(Client):
         
         """
         script = self.scripts.get('outE')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
 
-    def inE(self, _id, label=None, start=None, limit=None):
+    def inE(self, _id, label=None):
         """
         Returns the incoming edges of the vertex.
 
@@ -607,10 +604,10 @@ class Neo4jClient(Client):
 
         """
         script = self.scripts.get('inE')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
 
-    def bothE(self, _id, label=None, start=None, limit=None):
+    def bothE(self, _id, label=None):
         """
         Returns the incoming and outgoing edges of the vertex.
 
@@ -624,10 +621,10 @@ class Neo4jClient(Client):
         
         """
         script = self.scripts.get('bothE')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
 
-    def outV(self, _id, label=None, start=None, limit=None):
+    def outV(self, _id, label=None):
         """
         Returns the out-adjacent vertices of the vertex.
 
@@ -641,10 +638,10 @@ class Neo4jClient(Client):
 
         """
         script = self.scripts.get('outV')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
         
-    def inV(self, _id, label=None, start=None, limit=None):
+    def inV(self, _id, label=None):
         """
         Returns the in-adjacent vertices of the vertex.
 
@@ -658,10 +655,10 @@ class Neo4jClient(Client):
 
         """
         script = self.scripts.get('inV')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
         
-    def bothV(self, _id, label=None, start=None, limit=None):
+    def bothV(self, _id, label=None):
         """
         Returns the incoming- and outgoing-adjacent vertices of the vertex.
 
@@ -675,7 +672,7 @@ class Neo4jClient(Client):
 
         """
         script = self.scripts.get('bothV')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
 
     #: Index Proxy - Vertex
@@ -690,10 +687,13 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        default_config = {'type': "exact", 'provider': "lucene"}
-        index_config = kwds.pop("index_config", default_config) 
-        path = build_path(index_path, vertex_path)
-        params = dict(name=index_name, config=index_config)
+        index_type = kwds.pop("index_type", "exact")
+        provider = kwds.pop("provider", "lucene")
+        #keys = kwds.pop("keys",None)
+        #config = {'type':index_type,'provider':provider,'keys':str(keys)}
+        config = {'type':index_type, 'provider':provider}
+        path = build_path(index_path, "node")
+        params = dict(name=index_name, config=config)
         resp = self.request.post(path, params)
         resp._set_index_name(index_name)        
         return resp
@@ -705,7 +705,7 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        path = build_path(index_path,vertex_path)
+        path = build_path(index_path,"node")
         params = None
         return self.request.get(path, params)
 
@@ -725,22 +725,6 @@ class Neo4jClient(Client):
             resp._set_index_name(index_name)
         return resp
 
-    def get_or_create_vertex_index(self, index_name, *args, **kwds):
-        """
-        Get a Vertex Index or create it if it doesn't exist.
-
-        :param index_name: Index name.
-        :type index_name: str
-
-        :param index_config: Index configuration.
-        :type index_config: dict
-
-        :rtype: bulbs.neo4jserver.index.Index
-
-        """ 
-        # Neo4j's create index endpoint returns the index if it already exists
-        return self.create_vertex_index(index_name, *args, **kwds)
-
     def delete_vertex_index(self, index_name): 
         """
         Deletes the vertex index with the index_name.
@@ -751,7 +735,7 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        path = build_path(index_path, vertex_path, index_name)
+        path = build_path(index_path, "node", index_name)
         params = None
         return self.request.delete(path, params)
 
@@ -767,10 +751,8 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        default_config = {'type': "exact", 'provider': "lucene"}
-        index_config = kwds.pop("index_config", default_config) 
         path = build_path(index_path, edge_path)
-        params = dict(name=index_name, config=index_config)
+        params = dict(name=index_name)
         resp = self.request.post(path, params)
         resp._set_index_name(index_name)
         return resp
@@ -802,22 +784,6 @@ class Neo4jClient(Client):
             resp._set_index_name(index_name)
         return resp
 
-    def get_or_create_edge_index(self, index_name, *args, **kwds):
-        """
-        Get a Edge Index or create it if it doesn't exist.
-
-        :param index_name: Index name.
-        :type index_name: str
-
-        :param index_config: Index configuration.
-        :type index_config: dict
-
-        :rtype: bulbs.neo4jserver.index.Index
-
-        """ 
-        # Neo4j's create index endpoint returns the index if it already exists
-        return self.create_edge_index(index_name, *args, **kwds)
-
     def delete_edge_index(self, index_name):
         """
         Deletes the edge index with the index_name.
@@ -853,8 +819,8 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        uri = "%s/%s/%d" % (self.config.root_uri, vertex_path, _id)
-        path = build_path(index_path, vertex_path, index_name)
+        uri = "%s/%s/%d" % (self.config.root_uri, "node", _id)
+        path = build_path(index_path, "node", index_name)
         params = dict(key=key, value=value, uri=uri)
         return self.request.post(path, params)
 
@@ -874,55 +840,11 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        # converting all values to strings because that's how they're stored
-        path = build_path(index_path, vertex_path, index_name, key, value)
+        key, value = quote(key), quote(value)
+        path = build_path(index_path, "node", index_name, key, value)
         params = None
         return self.request.get(path, params)
 
-    def create_unique_vertex(self, index_name, key, value, data=None):
-        """
-        Create unique (based on the key / value pair) vertex with the properties
-        described by data.
-
-        :param index_name: Name of the index.
-        :type index_name: str
-
-        :param key: Name of the key.
-        :type key: str
-
-        :param value: Value of the key.
-        :type value: str
-
-        :param data: Properties of the new element.
-        :type data: dict
-
-        :rtype: Neo4jResponse
-
-        """
-        data = {} if data is None else data
-        data = self._remove_null_values(data)
-        path = (build_path(index_path, vertex_path, index_name) +
-                '?uniqueness=get_or_create')
-        params = {'key': key, 'value': value, 'properties': data}
-        return self.request.post(path, params)
-        
-    def query_vertex(self, index_name, query):
-        """
-        Queries the index and returns the Response.
-
-        :param index_name: Name of the index.
-        :type index_name: str
-
-        :param query: Lucene query string
-        :type query: str
-
-        :rtype: Neo4jResponse
-
-        """
-        path = build_path(index_path, vertex_path, index_name)
-        params = dict(query=query)
-        return self.request.get(path, params)
-
     def remove_vertex(self, index_name, _id, key=None, value=None):
         """
         Removes a vertex from the index and returns the Response.
@@ -939,7 +861,8 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        path = build_path(index_path, vertex_path, index_name ,key, value, _id)
+        key, value = quote(key), quote(value)
+        path = build_path(index_path, "node", index_name ,key, value, _id)
         params = None
         return self.request.delete(path, params)
         
@@ -985,28 +908,11 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
-        # converting all values to strings because that's how they're stored
+        key, value = quote(key), quote(value)
         path = build_path(index_path, edge_path, index_name, key, value)
         params = None
         return self.request.get(path, params)
 
-    def query_edge(self, index_name, query):
-        """
-        Queries the index and returns the Response.
-
-        :param index_name: Name of the index.
-        :type index_name: str
-
-        :param query: Lucene query string
-        :type query: str
-
-        :rtype: Neo4jResponse
-
-        """
-        path = build_path(index_path, edge_path, index_name)
-        params = dict(query=query)
-        return self.request.get(path, params)
-
     def remove_edge(self, index_name, _id, key=None, value=None):
         """
         Removes an edge from the index and returns the Response.
@@ -1026,6 +932,7 @@ class Neo4jClient(Client):
         :rtype: Neo4jResponse
 
         """
+        key, value = quote(key), quote(value)
         path = build_path(index_path, edge_path, index_name, key, value, _id)
         params = None
         return self.request.delete(path, params)
@@ -1105,7 +1012,7 @@ class Neo4jClient(Client):
 
         """
         data = self._remove_null_values(data)
-        edge_params = dict(outV=outV,label=label,inV=inV,label_var=self.config.label_var)
+        edge_params = dict(outV=outV,label=label,inV=inV)
         params = dict(data=data,index_name=index_name,keys=keys)
         params.update(edge_params)
         script = self.scripts.get("create_indexed_edge")
