@@ -3,7 +3,8 @@
 # Copyright 2012 James Thornton (http://jamesthornton.com)
 # BSD License (see LICENSE for details)
 #
-from bulbs.config import Config, DEBUG, INFO, WARNING, ERROR, CRITICAL
+
+from bulbs.config import Config
 from bulbs.element import Vertex, VertexProxy, Edge, EdgeProxy
 from bulbs.model import Node, NodeProxy, Relationship, RelationshipProxy
 
