@@ -21,7 +21,7 @@ from bulbs.utils import json, build_path, get_file_path, urlsplit, coerce_id
 
 
 # The default URIs
-REXSTER_URI = "http://localhost:8182/graphs/emptygraph"  # emptygraph has mock-tx enabled 
+REXSTER_URI = "http://localhost:8182/graphs/tinkergraph"
 SAIL_URI = "http://localhost:8182/graphs/sailgraph"
 
 # The logger defined in Config
@@ -81,20 +81,20 @@ class RexsterResult(Result):
         """
         return self.data['_type']
         
-    def get_data(self):
+    def get_map(self):
         """
-        Returns the element's property data.
+        Returns the element's property map.
 
         :rtype: dict
 
         """
-        property_data = dict()
+        property_map = dict()
         private_keys = ['_id','_type','_outV','_inV','_label']
         for key in self.data: # Python 3
             value = self.data[key]
             if key not in private_keys:
-                property_data.update({key:value})
-        return property_data
+                property_map.update({key:value})
+        return property_map
 
     def get_uri(self):
         """
@@ -119,7 +119,7 @@ class RexsterResult(Result):
 
         """
         _outV = self.data.get('_outV')
-        return coerce_id(_outV)
+        return int(_outV)
         
     def get_inV(self):
         """
@@ -129,7 +129,7 @@ class RexsterResult(Result):
 
         """
         _inV = self.data.get('_inV')
-        return coerce_id(_inV)
+        return int(_inV)
 
     def get_label(self):
         """
@@ -321,7 +321,7 @@ class RexsterClient(Client):
         self.request = self.request_class(self.config, self.type_system.content_type)
 
         # Rexster supports Gremlin so include the Gremlin-Groovy script library
-        self.scripts = GroovyScripts(self.config) 
+        self.scripts = GroovyScripts() 
 
         # Also include the Rexster-specific Gremlin-Groovy scripts
         scripts_file = get_file_path(__file__, "gremlin.groovy")
@@ -337,7 +337,7 @@ class RexsterClient(Client):
 
     # Gremlin
 
-    def gremlin(self, script, params=None, load=None): 
+    def gremlin(self, script, params=None): 
         """
         Executes a Gremlin script and returns the Response.
 
@@ -350,15 +350,12 @@ class RexsterClient(Client):
         :rtype: RexsterResponse
 
         """
-        params = dict(script=script, params=params)
-        if self.config.server_scripts is True:
-            params["load"] = load or [self.scripts.default_namespace]
-        return self.request.post(gremlin_path, params)
-
+        params = dict(script=script,params=params)
+        return self.request.post(gremlin_path,params)
 
     # Vertex Proxy
 
-    def create_vertex(self, data, keys=None):
+    def create_vertex(self, data):
         """
         Creates a vertex and returns the Response.
 
@@ -368,11 +365,8 @@ class RexsterClient(Client):
         :rtype: RexsterResponse
 
         """
-        if keys or self.config.autoindex is True:
-            index_name = self.config.vertex_index
-            return self.create_indexed_vertex(data, index_name, keys=keys)
         data = self._remove_null_values(data)
-        return self.request.post(vertex_path, data)
+        return self.request.post(vertex_path,data)
 
     def get_vertex(self, _id):
         """
@@ -398,7 +392,7 @@ class RexsterClient(Client):
         params = None
         return self.gremlin(script, params)
 
-    def update_vertex(self, _id, data, keys=None):
+    def update_vertex(self, _id, data):
         """
         Updates the vertex with the _id and returns the Response.
 
@@ -430,7 +424,7 @@ class RexsterClient(Client):
 
     # Edge Proxy
 
-    def create_edge(self, outV, label, inV, data={}, keys=None): 
+    def create_edge(self, outV, label, inV, data={}): 
         """
         Creates a edge and returns the Response.
         
@@ -449,9 +443,6 @@ class RexsterClient(Client):
         :rtype: RexsterResponse
 
         """
-        if keys or self.config.autoindex is True:
-            index_name = self.config.edge_index
-            return self.create_indexed_edge(outV,label,inV,data,index_name,keys=keys)
         data = self._remove_null_values(data)
         edge_data = dict(_outV=outV,_label=label,_inV=inV)
         data.update(edge_data)
@@ -481,7 +472,7 @@ class RexsterClient(Client):
         params = None
         return self.gremlin(script, params)
 
-    def update_edge(self,_id, data, keys=None):
+    def update_edge(self,_id,data):
         """
         Updates the edge with the _id and returns the Response.
 
@@ -513,7 +504,7 @@ class RexsterClient(Client):
 
     # Vertex Container
 
-    def outE(self,_id, label=None, start=None, limit=None):
+    def outE(self,_id, label=None):
         """
         Returns the outgoing edges of the vertex.
 
@@ -527,10 +518,10 @@ class RexsterClient(Client):
         
         """
         script = self.scripts.get('outE')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
 
-    def inE(self,_id, label=None, start=None, limit=None):
+    def inE(self,_id, label=None):
         """
         Returns the incoming edges of the vertex.
 
@@ -544,10 +535,10 @@ class RexsterClient(Client):
 
         """
         script = self.scripts.get('inE')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
 
-    def bothE(self,_id, label=None, start=None, limit=None):
+    def bothE(self,_id, label=None):
         """
         Returns the incoming and outgoing edges of the vertex.
 
@@ -561,10 +552,10 @@ class RexsterClient(Client):
         
         """
         script = self.scripts.get('bothE')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
 
-    def outV(self,_id, label=None, start=None, limit=None):
+    def outV(self,_id, label=None):
         """
         Returns the out-adjacent vertices of the vertex.
 
@@ -578,10 +569,10 @@ class RexsterClient(Client):
 
         """
         script = self.scripts.get('outV')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
         
-    def inV(self,_id, label=None, start=None, limit=None):
+    def inV(self,_id, label=None):
         """
         Returns the in-adjacent vertices of the vertex.
 
@@ -595,10 +586,10 @@ class RexsterClient(Client):
 
         """
         script = self.scripts.get('inV')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
         
-    def bothV(self,_id, label=None, start=None, limit=None):
+    def bothV(self,_id, label=None):
         """
         Returns the incoming- and outgoing-adjacent vertices of the vertex.
 
@@ -612,7 +603,7 @@ class RexsterClient(Client):
 
         """
         script = self.scripts.get('bothV')
-        params = dict(_id=_id,label=label,start=start,limit=limit)
+        params = dict(_id=_id,label=label)
         return self.gremlin(script,params)
 
     # Index Proxy - General
@@ -666,7 +657,7 @@ class RexsterClient(Client):
         script = self.scripts.get('get_or_create_vertex_index')
         params = dict(index_name=index_name, index_params=index_params)
         resp = self.gremlin(script, params)
-        #assert "MANUAL" in resp.content['results'][0]
+        assert "MANUAL" in resp.content['results'][0]
         result = {'name': index_name, 'type': 'manual', 'class': 'vertex'}
         resp.results = RexsterResult(result, self.config)
         return resp
@@ -719,7 +710,7 @@ class RexsterClient(Client):
         script = self.scripts.get('get_or_create_edge_index')
         params = dict(index_name=index_name, index_params=index_params)
         resp = self.gremlin(script, params)
-        #assert "MANUAL" in resp.content['results'][0]
+        assert "MANUAL" in resp.content['results'][0]
         result = {'name': index_name, 'type': 'manual', 'class': 'edge'}
         resp.results = RexsterResult(result, self.config)
         return resp
@@ -927,9 +918,7 @@ class RexsterClient(Client):
         data = self._remove_null_values(data)
         params = dict(data=data,index_name=index_name,keys=keys)
         script = self.scripts.get("create_indexed_vertex")
-        resp = self.gremlin(script,params)
-        resp.results = resp.one()
-        return resp
+        return self.gremlin(script,params)
     
     def update_indexed_vertex(self, _id, data, index_name, keys=None):
         """
@@ -983,13 +972,11 @@ class RexsterClient(Client):
 
         """
         data = self._remove_null_values(data)
-        edge_params = dict(outV=outV,label=label,inV=inV,label_var=self.config.label_var)
+        edge_params = dict(outV=outV,label=label,inV=inV)
         params = dict(data=data,index_name=index_name,keys=keys)
         params.update(edge_params)
         script = self.scripts.get("create_indexed_edge")
-        resp = self.gremlin(script,params)
-        resp.results = resp.one()
-        return resp
+        return self.gremlin(script,params)
         
     def update_indexed_edge(self, _id, data, index_name, keys=None):
         """
